pub struct GitIndex {
pub url: String,
pub local_path: PathBuf,
}Fields
url: Stringlocal_path: PathBufImplementations
Sourceimpl GitIndex
impl GitIndex
pub fn new(url: impl Into<String>, local_path: impl Into<PathBuf>) -> Self
Sourcepub fn refresh_if_stale(&self, ttl: Duration) -> Result<bool>
pub fn refresh_if_stale(&self, ttl: Duration) -> Result<bool>
Refresh only if the local clone is older than ttl.
Returns true when an actual network fetch was performed.
Sourcepub fn is_available(&self) -> bool
pub fn is_available(&self) -> bool
True when the local clone exists and has been fetched at least once.
Sourcepub fn local_path(&self) -> &Path
pub fn local_path(&self) -> &Path
Path to the local clone of this registry.